package App::jupiter;

our $VERSION = 1.06;

=head1 NAME

App::jupiter - an app that serves a river of news as a static page

=head1 DESCRIPTION

This is a stub module, see F<script/jupiter> for details of the app.

=head1 AUTHOR

Alex Schroeder

=head1 LICENSE

GNU Affero General Public License

=cut

1;
